@@ -16,11 +16,13 @@
 # under the License.
 
 """This module contains the Apache Livy sensor."""
-from typing import Any, Dict, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Union
 
 from airflow.providers.apache.livy.hooks.livy import LivyHook
 from airflow.sensors.base import BaseSensorOperator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class LivySensor(BaseSensorOperator):
@@ -28,21 +30,25 @@ class LivySensor(BaseSensorOperator):
     Monitor a Livy sessions for termination.
 
     :param livy_conn_id: reference to a pre-defined Livy connection
-    :type livy_conn_id: str
     :param batch_id: identifier of the monitored batch
-    :type batch_id: Union[int, str]
+        depends on the option that's being modified.
     """
 
-    template_fields = ('batch_id',)
+    template_fields: Sequence[str] = ('batch_id',)
 
-    @apply_defaults
     def __init__(
-        self, *, batch_id: Union[int, str], livy_conn_id: str = 'livy_default', **kwargs: Any
+        self,
+        *,
+        batch_id: Union[int, str],
+        livy_conn_id: str = 'livy_default',
+        extra_options: Optional[Dict[str, Any]] = None,
+        **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
+        self.batch_id = batch_id
         self._livy_conn_id = livy_conn_id
-        self._batch_id = batch_id
         self._livy_hook: Optional[LivyHook] = None
+        self._extra_options = extra_options or {}
 
     def get_hook(self) -> LivyHook:
         """
@@ -52,11 +58,11 @@ class LivySensor(BaseSensorOperator):
         :rtype: LivyHook
         """
         if self._livy_hook is None or not isinstance(self._livy_hook, LivyHook):
-            self._livy_hook = LivyHook(livy_conn_id=self._livy_conn_id)
+            self._livy_hook = LivyHook(livy_conn_id=self._livy_conn_id, extra_options=self._extra_options)
         return self._livy_hook
 
-    def poke(self, context: Dict[Any, Any]) -> bool:
-        batch_id = self._batch_id
+    def poke(self, context: "Context") -> bool:
+        batch_id = self.batch_id
 
         status = self.get_hook().get_batch_state(batch_id)
         return status in self.get_hook().TERMINAL_STATES
